@@ -89,6 +89,8 @@ class DataVarsBuilderLinux(linux.LinuxDataVars):
                     update.VariableClUpdateRepPath(section="update"),
                     update.VariableClUpdateRepName(section="update"),
                     update.VariableClUpdateRepUrl(section="update"),
+                    update.VariableClUpdateRepList(section="update"),
+                    update.VariableClUpdateBinhostSet(section="update"),
                     update.VariableClUpdateRep(section="update"),
                     update.VariableClUpdateRepRev(section="update"),
                     update.VariableClUpdateBranch(section="update",
@@ -243,9 +245,9 @@ class VariableOsBuilderLinuxShortname(BuilderLinux):
         self.label = _("Building short name")
 
 
-class VariableOsBuilderLinuxVer(BuilderLinux):
+class VariableOsBuilderLinuxVer(Variable):
     """Shortname of system"""
-    variable = "os_linux_ver"
+    value = "live"
 
     def init(self):
         self.label = _("Building system version")
